@@ -37,7 +37,7 @@ KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args),
       _cfg(KSharedConfig::openConfig(QStringLiteral("kwalletrc"), KConfig::NoGlobals))
 {
-    KAboutData *about = new KAboutData(QStringLiteral("kcmkwallet5"),
+    auto about = new KAboutData(QStringLiteral("kcmkwallet5"),
                                        i18n("KDE Wallet Control Module"),
                                        QStringLiteral(KWALLETMANAGER_VERSION_STRING),
                                        QString(),
@@ -49,7 +49,7 @@ KWalletConfig::KWalletConfig(QWidget *parent, const QVariantList &args)
     setAboutData(about);
     setNeedsAuthorization(true);
 
-    QVBoxLayout *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0, 0, 0, 0);
     _wcw = new WalletConfigWidget(this);
     vbox->addWidget(_wcw);
@@ -140,7 +140,7 @@ void KWalletConfig::newLocalWallet()
 
     _wcw->_localWallet->setCurrentIndex(_wcw->_localWallet->findText(n));
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void KWalletConfig::newNetworkWallet()
@@ -154,7 +154,7 @@ void KWalletConfig::newNetworkWallet()
 
     _wcw->_defaultWallet->setCurrentIndex(_wcw->_defaultWallet->findText(n));
 
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void KWalletConfig::launchManager()
@@ -170,7 +170,7 @@ void KWalletConfig::launchManager()
 
 void KWalletConfig::configChanged()
 {
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 void KWalletConfig::load()
@@ -229,7 +229,7 @@ void KWalletConfig::load()
         const QStringList apps = aa.readEntry(*i, QStringList());
         const QStringList denyapps = ad.readEntry(*i, QStringList());
         denykeys.removeAll(walletName);
-        QTreeWidgetItem *twi = new QTreeWidgetItem(_wcw->_accessList, QStringList() << walletName);
+        auto twi = new QTreeWidgetItem(_wcw->_accessList, QStringList() << walletName);
 
         for (QStringList::const_iterator j = apps.begin(), end = apps.end(); j != end; ++j) {
             new QTreeWidgetItem(twi, QStringList() << QString() << *j << i18n("Always Allow"));
@@ -240,13 +240,13 @@ void KWalletConfig::load()
     }
     for (QStringList::const_iterator i = denykeys.constBegin(), denykeysEnd = denykeys.constEnd(); i != denykeysEnd; ++i) {
         const QStringList denyapps = ad.readEntry(*i, QStringList());
-        QTreeWidgetItem *twi = new QTreeWidgetItem(_wcw->_accessList, QStringList() << *i);
+        auto twi = new QTreeWidgetItem(_wcw->_accessList, QStringList() << *i);
         for (QStringList::const_iterator j = denyapps.begin(), denyappsEnd = denyapps.end(); j != denyappsEnd; ++j) {
             new QTreeWidgetItem(twi, QStringList() << QString() << *j << i18n("Always Deny"));
         }
     }
     _wcw->_accessList->header()->setSectionResizeMode(QHeaderView::ResizeToContents);
-    emit changed(false);
+    Q_EMIT changed(false);
 }
 
 void KWalletConfig::save()
@@ -334,7 +334,7 @@ void KWalletConfig::save()
         kwalletd.call(QStringLiteral("reconfigure"));
     }
 
-    emit changed(false);
+    Q_EMIT changed(false);
 }
 
 void KWalletConfig::defaults()
@@ -351,7 +351,7 @@ void KWalletConfig::defaults()
     _wcw->_localWalletSelected->setChecked(false);
     _wcw->_localWallet->setCurrentIndex(0);
     _wcw->_accessList->clear();
-    emit changed(true);
+    Q_EMIT changed(true);
 }
 
 QString KWalletConfig::quickHelp() const
@@ -363,7 +363,7 @@ void KWalletConfig::customContextMenuRequested(const QPoint &pos)
 {
     QTreeWidgetItem *item = _wcw->_accessList->itemAt(pos);
     if (item && item->parent()) {
-        QMenu *m = new QMenu(this);
+        auto m = new QMenu(this);
         m->setTitle(item->parent()->text(0));
         m->addAction(i18n("&Delete"), this, &KWalletConfig::deleteEntry, Qt::Key_Delete);
         m->exec(_wcw->_accessList->mapToGlobal(pos));
@@ -376,7 +376,7 @@ void KWalletConfig::deleteEntry()
     QList<QTreeWidgetItem *> items = _wcw->_accessList->selectedItems();
     if (items.count() == 1 && items[0]) {
         delete items[0];
-        emit changed(true);
+        Q_EMIT changed(true);
     }
 }
 
