@@ -1,21 +1,8 @@
 /*
-   Copyright (C) 2003-2005 George Staikos <staikos@kde.org>
+    SPDX-FileCopyrightText: 2003-2005 George Staikos <staikos@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "../kwalletmanager_version.h"
 #include "kwalletmanager.h"
@@ -75,7 +62,7 @@ int main(int argc, char **argv)
     aboutData.setupCommandLine(&parser);
     parser.addOption(QCommandLineOption(QStringLiteral("show"), i18n("Show window on startup")));
     parser.addOption(QCommandLineOption(QStringLiteral("kwalletd"), i18n("For use by kwalletd only")));
-    parser.addOption(QCommandLineOption(QStringLiteral("name"), i18n("A wallet name")));
+    parser.addPositionalArgument(QStringLiteral("name"), i18n("A wallet name"));
     parser.process(a);
     aboutData.processCommandLine(&parser);
     KWalletManager wm;
@@ -90,7 +77,7 @@ int main(int argc, char **argv)
     }
 
     const QStringList arguments = parser.positionalArguments();
-    for (int i = 1; i < arguments.count(); ++i) {
+    for (int i = 0; i < arguments.count(); ++i) {
         QString fn = QFileInfo(arguments.at(i)).absoluteFilePath();
         if (QFile::exists(fn)) {
             QMimeDatabase mimeDb;
